@@ -1,4 +1,4 @@
-from typing import Any, Dict, Iterator, List, NamedTuple, Optional, Tuple
+from typing import Any, Iterator, NamedTuple, Optional
 
 from latex2mathml import commands
 from latex2mathml.exceptions import (
@@ -21,21 +21,21 @@ from latex2mathml.tokenizer import tokenize
 
 class Node(NamedTuple):
     token: str
-    children: Optional[Tuple[Any, ...]] = None
+    children: Optional[tuple[Any, ...]] = None
     delimiter: Optional[str] = None
     alignment: Optional[str] = None
     text: Optional[str] = None
-    attributes: Optional[Dict[str, str]] = None
+    attributes: Optional[dict[str, str]] = None
     modifier: Optional[str] = None
 
 
-def walk(data: str) -> List[Node]:
+def walk(data: str) -> list[Node]:
     tokens = tokenize(data)
     return _walk(tokens)
 
 
-def _walk(tokens: Iterator[str], terminator: Optional[str] = None, limit: int = 0) -> List[Node]:
-    group: List[Node] = []
+def _walk(tokens: Iterator[str], terminator: Optional[str] = None, limit: int = 0) -> list[Node]:
+    group: list[Node] = []
     token: str
     has_available_tokens = False
     for token in tokens:
@@ -67,7 +67,11 @@ def _walk(tokens: Iterator[str], terminator: Optional[str] = None, limit: int =
 
             if token == previous.token == commands.SUBSCRIPT:
                 raise DoubleSubscriptsError
-            if token == previous.token == commands.SUPERSCRIPT:
+            if (token == previous.token == commands.SUPERSCRIPT) and (
+                previous.children is not None
+                and len(previous.children) >= 2
+                and previous.children[1].token != commands.PRIME
+            ):
                 raise DoubleSuperscriptsError
 
             modifier = None
@@ -92,6 +96,22 @@ def _walk(tokens: Iterator[str], terminator: Optional[str] = None, limit: int =
             ):
                 children = tuple(_walk(tokens, terminator=terminator, limit=1))
                 node = Node(token=commands.SUBSUP, children=(*previous.children, *children), modifier=previous.modifier)
+            elif (
+                token == commands.SUPERSCRIPT
+                and previous.token == commands.SUPERSCRIPT
+                and previous.children is not None
+                and previous.children[1].token == commands.PRIME
+            ):
+                children = tuple(_walk(tokens, terminator=terminator, limit=1))
+
+                node = Node(
+                    token=commands.SUPERSCRIPT,
+                    children=(
+                        previous.children[0],
+                        Node(token=commands.BRACES, children=(previous.children[1], *children)),
+                    ),
+                    modifier=previous.modifier,
+                )
             else:
                 try:
                     children = tuple(_walk(tokens, terminator=terminator, limit=1))
@@ -106,6 +126,14 @@ def _walk(tokens: Iterator[str], terminator: Optional[str] = None, limit: int =
             except IndexError:
                 previous = Node(token="")  # left operand can be empty if not present
 
+            if (
+                previous.token == commands.SUPERSCRIPT
+                and previous.children is not None
+                and len(previous.children) >= 2
+                and previous.children[1].token != commands.PRIME
+            ):
+                raise DoubleSuperscriptsError
+
             if (
                 previous.token == commands.SUPERSCRIPT
                 and previous.children is not None
@@ -113,6 +141,12 @@ def _walk(tokens: Iterator[str], terminator: Optional[str] = None, limit: int =
                 and previous.children[1].token == commands.PRIME
             ):
                 node = Node(token=commands.SUPERSCRIPT, children=(previous.children[0], Node(token=commands.DPRIME)))
+            elif previous.token == commands.SUBSCRIPT and previous.children is not None:
+                node = Node(
+                    token=commands.SUBSUP,
+                    children=(*previous.children, Node(token=commands.PRIME)),
+                    modifier=previous.modifier,
+                )
             else:
                 node = Node(token=commands.SUPERSCRIPT, children=(previous, Node(token=commands.PRIME)))
         elif token in commands.COMMANDS_WITH_TWO_PARAMETERS:
@@ -344,7 +378,7 @@ def _walk(tokens: Iterator[str], terminator: Optional[str] = None, limit: int =
     return group
 
 
-def _make_subsup(node: Node) -> Tuple[str, Tuple[Node, ...]]:
+def _make_subsup(node: Node) -> tuple[str, tuple[Node, ...]]:
     # TODO: raise error instead of assertion
     assert node.token == commands.BRACES
     try:
